==> ffe-system-message-react-7.0.11.tgz: package/es/SystemErrorMessage.js <==
var _excluded = ["alert"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import { func, string, number, node, oneOf, bool } from 'prop-types';
import UtropstegnIkon from "@sb1/ffe-icons-react/es/utropstegn-ikon";
import SystemMessage from './SystemMessage';
export default function SystemErrorMessage(props) {
  var alert = props.alert,
    rest = _objectWithoutProperties(props, _excluded);
  return /*#__PURE__*/React.createElement(SystemMessage, _extends({
    modifier: "error",
    "aria-label": "Feilmelding",
    icon: /*#__PURE__*/React.createElement(UtropstegnIkon, {
      title: "Utropstegn, ikon"
    }),
    role: alert ? 'alert' : 'group'
  }, rest));
}
SystemErrorMessage.defaultProps = {
  animationLengthMs: 300,
  locale: 'nb',
  onClose: function onClose(f) {
    return f;
  },
  alert: true
};
SystemErrorMessage.propTypes = {
  animationLengthMs: number,
  /** The content of the system message */
  children: node.isRequired,
  /** Additional classes added to the surrounding div */
  className: string,
  /** Override the default icon - use with caution! */
  icon: node,
  /** 'nb', 'nn', or 'en' */
  locale: oneOf(['en', 'nb', 'nn']),
  /**
   * The type of system message. Used internally only-
   * @ignore
   **/
  modifier: oneOf(['error', 'info', 'success', 'news']),
  /** Callback for when the system message has been closed (after animation ends) */
  onClose: func,
  /** When false, role is not set to alert, avoids message from being read up immediately after page load. Default value is true. */
  alert: bool
};

==> ffe-system-message-react-8.0.0.tgz: package/es/SystemErrorMessage.js <==
var _excluded = ["alert"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import { func, string, number, node, oneOf, bool } from 'prop-types';
import _Symbol from '@sb1/ffe-symbols-react';
import SystemMessage from './SystemMessage';
export default function SystemErrorMessage(props) {
  var alert = props.alert,
    rest = _objectWithoutProperties(props, _excluded);
  return /*#__PURE__*/React.createElement(SystemMessage, _extends({
    modifier: "error",
    "aria-label": "Feilmelding",
    icon: /*#__PURE__*/React.createElement(_Symbol, {
      ariaLabel: "Utropstegn"
    }, "priority_high"),
    role: alert ? 'alert' : 'group'
  }, rest));
}
SystemErrorMessage.defaultProps = {
  animationLengthMs: 300,
  locale: 'nb',
  onClose: function onClose(f) {
    return f;
  },
  alert: true
};
SystemErrorMessage.propTypes = {
  animationLengthMs: number,
  /** The content of the system message */
  children: node.isRequired,
  /** Additional classes added to the surrounding div */
  className: string,
  /** 'nb', 'nn', or 'en' */
  locale: oneOf(['en', 'nb', 'nn']),
  /**
   * The type of system message. Used internally only-
   * @ignore
   **/
  modifier: oneOf(['error', 'info', 'success', 'news']),
  /** Callback for when the system message has been closed (after animation ends) */
  onClose: func,
  /** When false, role is not set to alert, avoids message from being read up immediately after page load. Default value is true. */
  alert: bool
};
